powered by
bgeva
"print"(x,...)
bgeva()
print.bgeva prints out the family, model equation, total number of observations, chosen tail parameter and estimated total effective degrees of freedom for the penalized or unpenalized model.
print.bgeva